list of askbot sites - My site
Description: Is there a list of public askbot sites? answers.ros.org - Robotics Operating System Answers site ask.fedoraproject.org - Fedora Linux answers.dotcloud.com - dotCloud - commercial web-application hosting platform asterisk-support.ru - Russian Asterisk user & developer community. ask.sagemath.org - Sage is a Mathematics engine written in Python. investmentqa.com - forum affiliated with moneyterms.co.uk SHAZAM econometrics software user community answers.gameduino.com macfaq.ru ask.libreoffice.org questions.astrobin.com - astrophotography and astronomy. Less active: http://www.dieselpushertalk.com http://ask.gi-link.com http://ask.xbase.ac.uk http://help.freeavailabledomains.com/ http://how2occupy.com/ http://fifooverflow.com/ This list is incomplete. Please add to the list once your site is up. Thanks.
Keywords: ,Askbot,forum,community

First time here? Check out the FAQ!

Hi there! Please sign in help
English ▼
tags users badges

| ALL UNANSWERED |  | Ask Your Question

6

# list of askbot sites

- askbot-sites

asked 2010-04-17 13:16:39 -0500

This post is a wiki. Anyone with karma >100 is welcome to improve it.

Is there a list of public askbot sites?

- answers.ros.org - Robotics Operating System Answers site
- ask.fedoraproject.org - Fedora Linux
- answers.dotcloud.com - dotCloud - commercial web-application hosting platform
- asterisk-support.ru - Russian Asterisk user & developer community.
- ask.sagemath.org - Sage is a Mathematics engine written in Python.
- investmentqa.com - forum affiliated with moneyterms.co.uk
- SHAZAM econometrics software user community
- answers.gameduino.com
- macfaq.ru
- ask.libreoffice.org
- questions.astrobin.com - astrophotography and astronomy.

Less active:

- http://www.dieselpushertalk.com
- http://ask.gi-link.com
- http://ask.xbase.ac.uk
- http://help.freeavailabledomains.com/
- http://how2occupy.com/
- http://fifooverflow.com/

This list is incomplete. Please add to the list once your site is up.

Thanks.

edit retag flag offensive close merge delete

## Comments

That would be nice! Right now it's just this site. My NMR Wiki Q&A still uses last years version of CNPROG... Will switch after we have a normal single-signon login app.
Evgeny ( 2010-04-17 17:53:58 -0500 )edit

Are there any websites that have a threaded view for the replies or does askbot support threaded replies?

Rishabh ( 2013-05-30 16:30:17 -0500 )edit

@Rishabh, we will not be supporting threaded comments any time soon, unless someone decides to pay us to develop this feature.

Evgeny ( 2013-05-30 17:00:44 -0500 )edit

@evegny do let me when can we discuss that

Rishabh ( 2013-06-02 12:05:53 -0500 )edit

help.openerp .com is the fastest growing AskBot site with 10,000 questions and 9,716 members in only 10 months.

fheopenerp ( 2013-12-07 18:06:15 -0500 )edit
add a comment

## 11 answers

Sort by » oldest newest most voted
« previous 1...1 2...2next »
2

answered 2010-08-18 15:52:28 -0500

William Stein
31 ●1 ●2

http://ask.sagemath.org -- a brand new site for questions and answers about http://sagemath.org

edit flag offensive delete link more

## Comments

great, thanks! please report any issues you discover.
Evgeny ( 2010-08-18 17:34:18 -0500 )edit
William, I've looked at your site and it seems that nobody can vote yet - you can lower the minimum rep for the upvote.
Evgeny ( 2010-08-18 17:45:48 -0500 )edit
add a comment
1

answered 2010-11-18 04:19:58 -0500

graeme
317 ●19 ●8 ●19

updated 2010-11-18 04:20:27 -0500

Another one as of today:

Investment Q & A

Hopefully, once I put the links in from my existing investment site it should get a reasonable number of visitors.

edit flag offensive delete link more

## Comments

The site is up very much thanks to Evgeny's help, especially the prompt fixing of various bugs my weird approach to things uncovered.
graeme ( 2010-11-18 05:08:12 -0500 )edit
add a comment
1

answered 2012-03-13 12:21:59 -0500

Prafulla T
21 ●2 ●1 ●4

Here is another askbot based site which is for Students to ask questions on various topics : http://studentask.in/

edit flag offensive delete link more

## Comments

Broken link.

kenorb ( 2014-07-01 06:06:17 -0500 )edit
add a comment
1

answered 2012-04-17 13:01:42 -0500

This post is a wiki. Anyone with karma >100 is welcome to improve it.

http://expats.qa is a resource for expats of all experience levels to exchange knowledge.

Having been active on a few other expat-related sites (most notably Sovereign Man Confidential and International Man), I got frustrated by some of the limitations I found with traditional forum-based knowledge sharing.

Askbot is a fantastic alternative to the traditional threaded discussion format:

- No open-ended discussions; the focus is exclusively on questions and answers.
- A karma system makes it possible to have an effectively self-moderated community.
- Tags are first-class citizens, making it easier for individuals with similar interests to find each other.

The site is in beta for the next few months until we've reached a critical mass of new users and experts. We look forward to seeing you there!

edit flag offensive delete link more
add a comment
1

answered 2012-04-22 15:45:19 -0500

luyu
83 ●2 ●2 ●6

AskLibO - Ask LibreOffice, official Q+A site of open-source cross-platform office suite

edit flag offensive delete link more
add a comment
1

answered 2014-02-21 11:49:07 -0500

chavers
11 ●1 ●1 ●2

google my friend

try this search:

    inurl:"scope:unanswered" inurl:"sort:answers-asc inurl:"page:1"

edit flag offensive delete link more
add a comment
0

answered 2014-08-15 10:35:02 -0500

ezequielc
1 ●1 ●1 ●1

http://tiraduvidas.net is general topics Q&A in portuguese.

edit flag offensive delete link more
add a comment
0

answered 2012-03-12 17:12:19 -0500

This post is a wiki. Anyone with karma >100 is welcome to improve it.

http://ask.unixmen.com all about Unix/linux/opensources The official askbot fro http://www.unixmen.com

edit flag offensive delete link more
add a comment
0

answered 2012-04-23 12:38:42 -0500

This post is a wiki. Anyone with karma >100 is welcome to improve it.

askCRE - Commercial Real Estate Q&A

edit flag offensive delete link more
add a comment
0

answered 2012-03-01 13:57:50 -0500

This post is a wiki. Anyone with karma >100 is welcome to improve it.

Ask Rascal: The Q&A site for our meta programming language.

edit flag offensive delete link more
add a comment
« previous 1...1 2...2next »

## Your Answer

Please start posting anonymously - your entry will be published after you log in or create a new account.

Add Answer

[hide preview]
community wiki (karma is not awarded & many others can edit wiki post)

## Question Tools

10 followers

## Stats

Asked: 2010-04-17 13:16:39 -0500

Seen: 15,119 times

Last updated: Aug 15 '14

## Related questions

Are there sites that use AskBot?

how much can Askbot be customized, the code changed

how can I test all the module and admin function during my developing

cookie domain-subdomain

Copyright Askbot, 2010-2011. Content on this site is licensed under a Creative Commons Attribution Share Alike 3.0 license.
Powered by Askbot version 0.7.54
( 2016-08-22 10:32:01 -0500 )edit
none